==> nuo-1.0.5.tgz: package/es/index.js <==
/*!
 * NUO v1.0.5
 * (c) 2018 crossjs
 * Released under the MIT License.
 */
var setImmediate = require('core-js/library/fn/set-immediate');

function Nuo (fn) {
  var this$1 = this;

  if (!isNuo(this)) { throw new TypeError('Promises must be constructed via new') }
  if (!isFunction(fn)) { throw new TypeError('The first argument must be a function') }
  // state
  this._s = null;
  // value
  this._v = null;
  // progress
  this._p = null;
  // deferred
  this._d = [];

  doResolve(
    fn,
    function (value) { return resolve.call(this$1, value); },
    function (reason) { return reject.call(this$1, reason); },
    function (progress) { return notify.call(this$1, progress); });
}

function handle (deferred) {
  var this$1 = this;

  if (this._s === null) {
    this._d.push(deferred);
    if (deferred.onProgress) {
      if (this._p !== null) {
        setImmediate(function () {
          deferred.onProgress(this$1._p);
        });
      }
    }
    return
  }

  setImmediate(function () {
    var cb = this$1._s ? deferred.onFulfilled : deferred.onRejected;
    if (cb === null) {
      (this$1._s ? deferred.resolve : deferred.reject)(this$1._v);
      return
    }
    var ret;
    try {
      ret = cb(this$1._v);
    } catch (e) {
      deferred.reject(e);
      return
    }
    deferred.resolve(ret);
  });
}

function resolve (newValue) {
  var this$1 = this;

  try {
    // Promise Resolution Procedure: https://github.com/promises-aplus/promises-spec#the-promise-resolution-procedure
    if (newValue === this) {
      throw new TypeError('A promise cannot be resolved with itself.')
    }

    if (newValue && (isObject(newValue) || isFunction(newValue))) {
      var then = newValue.then;
      if (isFunction(then)) {
        var fn = function (resolve, reject, notify) {
          then.call(newValue, resolve, reject, notify);
        };
        doResolve(
          fn,
          function (value) { return resolve.call(this$1, value); },
          function (reason) { return reject.call(this$1, reason); },
          function (progress) { return notify.call(this$1, progress); });
        return
      }
    }

    this._s = true;
    this._v = newValue;
    finale.call(this);
  } catch (e) {
    reject.call(this, e);
  }
}

function reject (newValue) {
  this._s = false;
  this._v = newValue;
  finale.call(this);
}

function notify (progress) {
  this._p = progress;
  finale.call(this, true);
}

function finale (keep) {
  var this$1 = this;

  for (var i = 0, d = this._d, len = d.length; i < len; i++) {
    handle.call(this$1, d[i]);
  }
  if (!keep) {
    this._d = null;
  }
}

function Handler (onFulfilled, onRejected, onProgress, resolve, reject, notify) {
  this.onFulfilled = isFunction(onFulfilled) ? onFulfilled : null;
  this.onRejected = isFunction(onRejected) ? onRejected : null;
  this.onProgress = isFunction(onProgress) ? onProgress : null;
  this.resolve = resolve;
  this.reject = reject;
  this.notify = notify;
}

/**
 * Take a potentially misbehaving resolver function and make sure
 * onFulfilled and onRejected are only called once.
 *
 * Makes no guarantees about asynchrony.
 */
function doResolve (fn, onFulfilled, onRejected, onProgress) {
  var done = false;
  try {
    fn(function (value) {
      if (done) { return }
      done = true;
      onFulfilled(value);
    }, function (reason) {
      if (done) { return }
      done = true;
      onRejected(reason);
    }, function (progress) {
      if (done) { return }
      onProgress(progress);
    });
  } catch (e) {
    if (done) { return }
    done = true;
    onRejected(e);
  }
}

Nuo.prototype['catch'] = function (onRejected) {
  return this.then(null, onRejected)
};

Nuo.prototype['finally'] = function (done) {
  return this.then(
    function (value) { return Nuo.resolve(done()).then(function () { return value; }); },
    function (reason) { return Nuo.resolve(done()).then(function () {
      throw reason
    }); })
};

Nuo.prototype.progress = function (onProgress) {
  return this.then(null, null, onProgress)
};

Nuo.prototype.then = function (onFulfilled, onRejected, onProgress) {
  var this$1 = this;

  return new Nuo(function (resolve, reject, notify) {
    handle.call(this$1, new Handler(onFulfilled, onRejected, onProgress, resolve, reject, notify));
  })
};

Nuo.resolve = function (value) {
  if (value && isNuo(value)) {
    return value
  }

  return new Nuo(function (resolve) { return resolve(value); })
};

Nuo.reject = function (value) { return new Nuo(function (resolve, reject) { return reject(value); }); };

Nuo.notify = function (value) { return new Nuo(function (resolve, reject, notify) { return notify(value); }); };

Nuo.all = function (values) {
  return new Nuo(function (resolve, reject, notify) {
    if (values.length === 0) { return resolve([]) }
    var remaining = values.length;

    function res (i, val) {
      try {
        if (val && (isObject(val) || isFunction(val))) {
          var then = val.then;
          if (isFunction(then)) {
            then.call(val, function (val) {
              res(i, val);
            }, reject, notify);
            return
          }
        }
        values[i] = val;
        if (--remaining === 0) {
          resolve(values);
        }
      } catch (e) {
        reject(e);
      }
    }
    for (var i = 0, len = values.length; i < len; i++) {
      res(i, values[i]);
    }
  })
};

Nuo.race = function (values) { return new Nuo(function (resolve, reject, notify) {
  for (var i = 0, len = values.length; i < len; i++) {
    Nuo.resolve(values[i]).then(resolve, reject, notify);
  }
}); };

function isNuo (val) {
  return val instanceof Nuo
}

function isObject (val) {
  return typeof val === 'object'
}

function isFunction (val) {
  return typeof val === 'function'
}

export default Nuo;

==> nuo-1.1.0.tgz: package/es/index.js <==
/*!
 * NUO v1.1.0
 * (c) 2018 crossjs
 * Released under the MIT License.
 */
import setImmediate from 'core-js/library/fn/set-immediate';

function Nuo (fn) {
  var this$1 = this;

  if (!isNuo(this)) { throw new TypeError('Promises must be constructed via new') }
  if (!isFunction(fn)) { throw new TypeError('The first argument must be a function') }
  // state
  this._s = null;
  // value
  this._v = null;
  // progress
  this._p = null;
  // deferred
  this._d = [];

  doResolve(
    fn,
    function (value) { return resolve.call(this$1, value); },
    function (reason) { return reject.call(this$1, reason); },
    function (progress) { return notify.call(this$1, progress); });
}

function handle (deferred) {
  var this$1 = this;

  if (this._s === null) {
    this._d.push(deferred);
    if (deferred.onProgress) {
      if (this._p !== null) {
        setImmediate(function () {
          deferred.onProgress(this$1._p);
        });
      }
    }
    return
  }

  setImmediate(function () {
    var cb = this$1._s ? deferred.onFulfilled : deferred.onRejected;
    if (cb === null) {
      (this$1._s ? deferred.resolve : deferred.reject)(this$1._v);
    } else {
      try {
        var ret = cb(this$1._v);
        deferred.resolve(ret);
      } catch (e) {
        deferred.reject(e);
      }
    }
  });
}

function resolve (newValue) {
  var this$1 = this;

  try {
    // Promise Resolution Procedure: https://github.com/promises-aplus/promises-spec#the-promise-resolution-procedure
    if (newValue === this) {
      throw new TypeError('A promise cannot be resolved with itself.')
    }

    if (newValue && (isObject(newValue) || isFunction(newValue))) {
      var then = newValue.then;
      if (isFunction(then)) {
        var fn = function (resolve, reject, notify) {
          then.call(newValue, resolve, reject, notify);
        };
        doResolve(
          fn,
          function (value) { return resolve.call(this$1, value); },
          function (reason) { return reject.call(this$1, reason); },
          function (progress) { return notify.call(this$1, progress); });
        return
      }
    }

    this._s = true;
    this._v = newValue;
    finale.call(this);
  } catch (e) {
    reject.call(this, e);
  }
}

function reject (newValue) {
  this._s = false;
  this._v = newValue;
  finale.call(this);
}

function notify (progress) {
  this._p = progress;
  finale.call(this, true);
}

function finale (keepDeferred) {
  var this$1 = this;

  for (var i = 0, d = this._d, len = d.length; i < len; i++) {
    handle.call(this$1, d[i]);
  }
  if (!keepDeferred) {
    this._d = null;
  }
}

function Handler (onFulfilled, onRejected, onProgress, resolve, reject, notify) {
  this.onFulfilled = isFunction(onFulfilled) ? onFulfilled : null;
  this.onRejected = isFunction(onRejected) ? onRejected : null;
  this.onProgress = isFunction(onProgress) ? onProgress : null;
  this.resolve = resolve;
  this.reject = reject;
  this.notify = notify;
}

/**
 * Take a potentially misbehaving resolver function and make sure
 * onFulfilled and onRejected are only called once.
 *
 * Makes no guarantees about asynchrony.
 */
function doResolve (fn, onFulfilled, onRejected, onProgress) {
  var done = false;
  try {
    fn(function (value) {
      if (done) { return }
      done = true;
      onFulfilled(value);
    }, function (reason) {
      if (done) { return }
      done = true;
      onRejected(reason);
    }, function (progress) {
      if (done) { return }
      onProgress(progress);
    });
  } catch (e) {
    if (done) { return }
    done = true;
    onRejected(e);
  }
}

Nuo.prototype['catch'] = function (onRejected) {
  return this.then(null, onRejected)
};

Nuo.prototype['finally'] = function (done) {
  return this.then(
    function (value) { return Nuo.resolve(done()).then(function () { return value; }); },
    function (reason) { return Nuo.resolve(done()).then(function () {
      throw reason
    }); })
};

Nuo.prototype.progress = function (onProgress) {
  return this.then(null, null, onProgress)
};

Nuo.prototype.then = function (onFulfilled, onRejected, onProgress) {
  var this$1 = this;

  return new Nuo(function (resolve, reject, notify) {
    handle.call(this$1, new Handler(onFulfilled, onRejected, onProgress, resolve, reject, notify));
  })
};

Nuo.resolve = function (value) { return isNuo(value) ? value : new Nuo(function (resolve) { return resolve(value); }); };

Nuo.reject = function (value) { return new Nuo(function (resolve, reject) { return reject(value); }); };

Nuo.notify = function (value) { return new Nuo(function (resolve, reject, notify) { return notify(value); }); };

Nuo.all = function (values) {
  return new Nuo(function (resolve, reject, notify) {
    if (values.length === 0) { return resolve([]) }
    var remaining = values.length;

    function res (i, val) {
      try {
        if (val && (isObject(val) || isFunction(val))) {
          var then = val.then;
          if (isFunction(then)) {
            then.call(val, function (val) {
              res(i, val);
            }, reject, notify);
            return
          }
        }
        values[i] = val;
        if (--remaining === 0) {
          resolve(values);
        }
      } catch (e) {
        reject(e);
      }
    }
    // 各数组项都会被执行到，
    // 即时中途出现被拒绝项。
    for (var i = 0, len = remaining; i < len; i++) {
      res(i, values[i]);
    }
  })
};

Nuo.race = function (values) { return new Nuo(function (resolve, reject, notify) {
  // 各数组项都会被执行到，
  // 即时中途出现被拒绝项。
  for (var i = 0, len = values.length; i < len; i++) {
    Nuo.resolve(values[i]).then(resolve, reject, notify);
  }
}); };

Nuo.any = function (values) {
  return new Nuo(function (resolve, reject, notify) {
    if (values.length === 0) { return reject() }
    var remaining = values.length;

    function res (i, val) {
      try {
        if (val && (isObject(val) || isFunction(val))) {
          var then = val.then;
          if (isFunction(then)) {
            then.call(val, function (val) {
              res(i, val);
            }, reject, notify);
            return
          }
        }
        resolve(val);
      } catch (e) {
        reject(e);
      }
      if (--remaining === 0) {
        reject();
      }
    }
    // 各数组项都会被执行到，
    // 即时中途出现被拒绝项。
    for (var i = 0, len = remaining; i < len; i++) {
      res(i, values[i]);
    }
  })
};

function isNuo (val) {
  return val instanceof Nuo
}

function isObject (val) {
  return typeof val === 'object'
}

function isFunction (val) {
  return typeof val === 'function'
}

export default Nuo;
